@@ -1,7 +1,8 @@
 #include <CoreFoundation/CFString.h>
 #include <CoreAudio/CoreAudio.h>
 
-#include "mac-helpers.h"
+#include <util/apple/cfstring-utils.h>
+
 #include "audio-device-enum.h"
 
 /* ugh, because mac has no means of capturing output, we have to basically
@@ -9,15 +10,18 @@
 static inline bool device_is_input(char *device)
 {
 	return astrstri(device, "soundflower") == NULL &&
-	       astrstri(device, "wavtap")      == NULL &&
-	       astrstri(device, "soundsiphon") == NULL;
+	       astrstri(device, "wavtap") == NULL &&
+	       astrstri(device, "soundsiphon") == NULL &&
+	       astrstri(device, "ishowu") == NULL &&
+	       astrstri(device, "blackhole") == NULL &&
+	       astrstri(device, "loopback") == NULL;
 }
 
 static inline bool enum_success(OSStatus stat, const char *msg)
 {
 	if (stat != noErr) {
-		blog(LOG_WARNING, "[coreaudio_enum_devices] %s failed: %d",
-				msg, (int)stat);
+		blog(LOG_WARNING, "[coreaudio_enum_devices] %s failed: %d", msg,
+		     (int)stat);
 		return false;
 	}
 
@@ -25,22 +29,20 @@ static inline bool enum_success(OSStatus stat, const char *msg)
 }
 
 typedef bool (*enum_device_proc_t)(void *param, CFStringRef cf_name,
-		CFStringRef cf_uid, AudioDeviceID id);
+				   CFStringRef cf_uid, AudioDeviceID id);
 
 static bool coreaudio_enum_device(enum_device_proc_t proc, void *param,
-		AudioDeviceID id)
+				  AudioDeviceID id)
 {
-	UInt32      size      = 0;
-	CFStringRef cf_name   = NULL;
-	CFStringRef cf_uid    = NULL;
-	bool        enum_next = true;
-	OSStatus    stat;
+	UInt32 size = 0;
+	CFStringRef cf_name = NULL;
+	CFStringRef cf_uid = NULL;
+	bool enum_next = true;
+	OSStatus stat;
 
-	AudioObjectPropertyAddress addr = {
-		kAudioDevicePropertyStreams,
-		kAudioDevicePropertyScopeInput,
-		kAudioObjectPropertyElementMaster
-	};
+	AudioObjectPropertyAddress addr = {kAudioDevicePropertyStreams,
+					   kAudioDevicePropertyScopeInput,
+					   kAudioObjectPropertyElementMaster};
 
 	/* check to see if it's a mac input device */
 	AudioObjectGetPropertyDataSize(id, &addr, 0, NULL, &size);
@@ -71,27 +73,25 @@ fail:
 
 static void enum_devices(enum_device_proc_t proc, void *param)
 {
-	AudioObjectPropertyAddress addr = {
-		kAudioHardwarePropertyDevices,
-		kAudioObjectPropertyScopeGlobal,
-		kAudioObjectPropertyElementMaster
-	};
+	AudioObjectPropertyAddress addr = {kAudioHardwarePropertyDevices,
+					   kAudioObjectPropertyScopeGlobal,
+					   kAudioObjectPropertyElementMaster};
 
-	UInt32        size = 0;
-	UInt32        count;
-	OSStatus      stat;
+	UInt32 size = 0;
+	UInt32 count;
+	OSStatus stat;
 	AudioDeviceID *ids;
 
 	stat = AudioObjectGetPropertyDataSize(kAudioObjectSystemObject, &addr,
-			0, NULL, &size);
+					      0, NULL, &size);
 	if (!enum_success(stat, "get kAudioObjectSystemObject data size"))
 		return;
 
-	ids   = bmalloc(size);
+	ids = bmalloc(size);
 	count = size / sizeof(AudioDeviceID);
 
-	stat = AudioObjectGetPropertyData(kAudioObjectSystemObject, &addr,
-			0, NULL, &size, ids);
+	stat = AudioObjectGetPropertyData(kAudioObjectSystemObject, &addr, 0,
+					  NULL, &size, ids);
 
 	if (enum_success(stat, "get kAudioObjectSystemObject data"))
 		for (UInt32 i = 0; i < count; i++)
@@ -103,20 +103,20 @@ static void enum_devices(enum_device_proc_t proc, void *param)
 
 struct add_data {
 	struct device_list *list;
-	bool               input;
+	bool input;
 };
 
 static bool coreaudio_enum_add_device(void *param, CFStringRef cf_name,
-		CFStringRef cf_uid, AudioDeviceID id)
+				      CFStringRef cf_uid, AudioDeviceID id)
 {
-	struct add_data    *data = param;
+	struct add_data *data = param;
 	struct device_item item;
 
 	memset(&item, 0, sizeof(item));
 
-	if (!cf_to_dstr(cf_name, &item.name))
+	if (!cfstr_copy_dstr(cf_name, kCFStringEncodingUTF8, &item.name))
 		goto fail;
-	if (!cf_to_dstr(cf_uid,  &item.value))
+	if (!cfstr_copy_dstr(cf_uid, kCFStringEncodingUTF8, &item.value))
 		goto fail;
 
 	if (data->input || !device_is_input(item.value.array))
@@ -136,18 +136,18 @@ void coreaudio_enum_devices(struct device_list *list, bool input)
 }
 
 struct device_id_data {
-	CFStringRef   uid;
+	CFStringRef uid;
 	AudioDeviceID *id;
-	bool          found;
+	bool found;
 };
 
 static bool get_device_id(void *param, CFStringRef cf_name, CFStringRef cf_uid,
-		AudioDeviceID id)
+			  AudioDeviceID id)
 {
 	struct device_id_data *data = param;
 
 	if (CFStringCompare(cf_uid, data->uid, 0) == 0) {
-		*data->id   = id;
+		*data->id = id;
 		data->found = true;
 		return false;
 	}
